@@ -74,8 +74,12 @@ GraphCanvas::GraphCanvas(QWidget *parent) :
     rtrace->pen = pen5;  //TODO: tidy
     graph.AddItem(rtrace);
 
+    ZZeroLine = new GraphHorizLine(&graph,yscale2);
+    ZZeroLine->pen = QPen(Qt::black,0);
+    graph.AddItem(ZZeroLine);
+
     ZTargetline = new GraphHorizLine(&graph,yscale2);
-    ZTargetline->pen = QPen(Qt::black,0,Qt::DashLine);
+    ZTargetline->pen = QPen(QColor(255,85,0),0,Qt::DashLine);
     graph.AddItem(ZTargetline);
 
     SWRTargetline = new GraphHorizLine(&graph,yscale1);
