@@ -20,7 +20,7 @@ public:
     GraphScale *xscale,*yscale1, *yscale2;
     GraphTrace *swrtrace, *ztrace, *xtrace, *rtrace;
     GraphVertLine *swrminline;
-    GraphHorizLine *ZTargetline,*SWRTargetline;
+    GraphHorizLine *ZZeroLine, *ZTargetline,*SWRTargetline;
 
 signals:
     void cursorMoved(double pos);
