@@ -38,17 +38,17 @@ int ScanData::GetPointCount()
 
 void ScanData::UpdateStats()
 {
-    swr_min_idx = Z_min_idx = X_min_idx = X2_min_idx = R_min_idx = Z_max_idx = X2_max_idx = X_max_idx = R_max_idx = swr_max_idx = 0;
+    swr_min_idx = Z_min_idx = X_min_idx = R_min_idx = Z_max_idx = X_max_idx = R_max_idx = swr_max_idx = 0;
 
     freq_start = points.front().freq;
     freq_end = points.back().freq;
 
     for (unsigned int i=0;i<points.size();i++)
     {
-        double
-           n = points[i].Z*points[i].Z - points[i].R*points[i].R;
+        //double
+           //n = points[i].Z*points[i].Z - points[i].R*points[i].R;
 
-        points[i].X2 = copysign(sqrt(abs(n)),n);
+        //points[i].X2 = copysign(sqrt(abs(n)),n);
 //printf("i=%d, swr=%lf, f=%lf\n",i,points[i].swr,points[i].freq);
         if (points[i].swr < points[swr_min_idx].swr) { swr_min_idx=i; }
         if (points[i].swr > points[swr_max_idx].swr) { swr_max_idx=i; }
@@ -58,8 +58,8 @@ void ScanData::UpdateStats()
         if (points[i].X > points[X_max_idx].X) { X_max_idx=i; }
         if (points[i].R < points[R_min_idx].R) { R_min_idx=i; }
         if (points[i].R > points[R_max_idx].R) { R_max_idx=i; }
-        if (points[i].X2 < points[X2_min_idx].X2) { X2_min_idx=i; }
-        if (points[i].X2 > points[X2_max_idx].X2) { X2_max_idx=i; }
+        //if (points[i].X2 < points[X2_min_idx].X2) { X2_min_idx=i; }
+        //if (points[i].X2 > points[X2_max_idx].X2) { X2_max_idx=i; }
     }
     for (int i=swr_bw_lo_idx=swr_min_idx;i>=0 && i<(int)points.size() && points[i].swr<=Config::swr_bw_max;i--)
         swr_bw_lo_idx=i;
@@ -154,3 +154,11 @@ bool ScanData::fromDom(QDomElement &e0)
 
     return true;
 }
+
+void Sample::fromRaw(double vf,double vr,double vz,double va)
+{
+    swr = (vf + vr) / (vf - vr);
+    Z = 50.0 * vz/va;
+    R = ((2500.0 + Z*Z) * swr)/(50.0 * (swr*swr + 1));
+    X = Z>R ? sqrt(Z*Z - R*R) : -sqrt(-Z*Z + R*R);
+}
