@@ -12,8 +12,9 @@ class Sample
 {
 public:
     Sample();
+    void fromRaw(double vf,double vr,double vz,double va);
 
-    double freq, swr, R, Z, X, X2;
+    double freq, swr, R, Z, X;
 };
 
 class ScanData
@@ -32,7 +33,7 @@ public:
 
     //timestamp??
     double freq_start,freq_end;
-    int swr_min_idx, swr_max_idx, Z_min_idx, Z_max_idx, X_min_idx, X_max_idx, X2_min_idx, X2_max_idx, R_min_idx, R_max_idx;
+    int swr_min_idx, swr_max_idx, Z_min_idx, Z_max_idx, X_min_idx, X_max_idx, R_min_idx, R_max_idx;
     int swr_bw_lo_idx,swr_bw_hi_idx;
 };
 
