@@ -28,21 +28,25 @@ printf("SerialLink::Init: dev %s\n",dev);
         cfmakeraw(&termattr);
 printf("\tc_cflag=%x\n",termattr.c_cflag);
         termattr.c_oflag &= ~(ONLCR);
+#if defined(__APPLE__) && defined(__MACH__)
+        termattr.c_cflag &= ~(CRTSCTS|PARENB|CSTOPB);
+#else
         termattr.c_cflag &= ~(CRTSCTS|PARENB|CSTOPB|CBAUD);
+#endif
         termattr.c_cflag |= CS8 | CLOCAL;
 printf("\tc_cflag=%x\n",termattr.c_cflag);
         switch (speed)
         {
-          case 300: termattr.c_cflag |= B300; break;
-          case 600: termattr.c_cflag |= B600; break;
-          case 1200: termattr.c_cflag |= B1200; break;
-          case 2400: termattr.c_cflag |= B2400; break;
-          case 4800: termattr.c_cflag |= B4800; break;
-          case 9600: termattr.c_cflag |= B9600; break;
-          case 19200: termattr.c_cflag |= B19200; break;
-          case 38400: termattr.c_cflag |= B38400; break;
-          case 57600: termattr.c_cflag |= B57600; break;
-          case 115200: termattr.c_cflag |= B115200; break;
+          case 300: cfsetspeed(&termattr, B300); break;
+          case 600: cfsetspeed(&termattr, B600); break;
+          case 1200: cfsetspeed(&termattr, B1200); break;
+          case 2400: cfsetspeed(&termattr, B2400); break;
+          case 4800: cfsetspeed(&termattr, B4800); break;
+          case 9600: cfsetspeed(&termattr, B9600); break;
+          case 19200: cfsetspeed(&termattr, B19200); break;
+          case 38400: cfsetspeed(&termattr, B38400); break;
+          case 57600: cfsetspeed(&termattr, B57600); break;
+          case 115200: cfsetspeed(&termattr, B115200); break;
         }
 printf("\tc_cflag=%x\n",termattr.c_cflag);
         tcsetattr(devfd, TCSANOW, &termattr);
@@ -157,7 +161,7 @@ printf("RxFlush: %c\n",rxbuff[rxbufflen]);
     }
 }
 
-void SerialLink::TxCmd(char *cmd)
+void SerialLink::TxCmd(const char *cmd)
 {
     if (devfd != -1)
     {
@@ -171,7 +175,7 @@ int SerialLink::RxLine()
 {
 
     pollfd fds[] = {{devfd, POLLIN, 0 }};
-    int timeout = 10000;    //10sec, move somewhere
+    int timeout = 4000;    //10sec, move somewhere
     int pstatus,rstatus;
 
     for (rxbufflen=0;;)
