@@ -11,7 +11,8 @@ SettingsDlg::SettingsDlg(QWidget *parent) :
 
     connect(ui->buttonBox, SIGNAL(accepted()), this, SLOT(Slot_Accept()));
 
-    ui->swr_bw_min->setValue(Config::swr_bw_max);
+    ui->swr_max->setValue(Config::swr_bw_max);
+    ui->swr_bw_max->setValue(Config::swr_bw_max);
     ui->Z_Target->setValue(Config::Z_Target);
 }
 
@@ -19,7 +20,8 @@ void SettingsDlg::Slot_Accept()
 {
     using namespace Config;
 
-    swr_bw_max = ui->swr_bw_min->value();
+    swr_max = ui->swr_max->value();
+    swr_bw_max = ui->swr_bw_max->value();
     Z_Target = ui->Z_Target->value();
     write();
 }
